#+ELEVENTY_COLLECTIONS: _posts
#+ELEVENTY_BASE_DIR: ~/proj/static-blog/
#+ELEVENTY_CATEGORIES+: emacs
#+ELEVENTY_LAYOUT: layouts/post

* Using Embark and qrencode to show a QR code for the Org Mode link at point :emacs:org:
:PROPERTIES:
:CUSTOM_ID: embark-qr
:EXPORT_DATE: 2024-01-10T15:46:11-0500
:EXPORT_ELEVENTY_PERMALINK: /blog/2024/01/using-embark-and-qrencode-to-show-a-qr-code-for-the-org-mode-link-at-point/
:EXPORT_ELEVENTY_FILE_NAME: blog/2024/01/using-embark-and-qrencode-to-show-a-qr-code-for-the-org-mode-link-at-point/
:EXPORT_MODIFIED: 2024-01-12T07:31:44-0500
:END:

#+begin_update
[2024-01-12]: Added some code to display the QR code on the right side.
#+end_update

John Kitchin includes [[https://www.youtube.com/watch?v=rGGAr1AWkTc][little QR codes in his videos]]. I
thought that was a neat touch that makes it easier for
people to jump to a link while they're watching. I'd like to
make it easier to show QR codes too. The following code lets
me show a QR code for the Org link at point. Since many of
my links use custom Org link types that aren't that useful
for people to scan, the code reuses the link resolution code
from [[dotemacs:web-link]] so that I can get the regular
~https:~ link.

#+begin_src emacs-lisp
(defun my-org-link-qr (url)
	"Display a QR code for URL in a buffer."
	(let ((buf (save-window-excursion (qrencode--encode-to-buffer (my-org-stored-link-as-url url)))))
		(display-buffer-in-side-window buf '((side . right)))))

(use-package qrencode
	:config
	(with-eval-after-load 'embark
		(define-key embark-org-link-map (kbd "q") #'my-org-link-qr)))
#+end_src

#+CAPTION: Screenshot of QR code for the link at point
[[file:images/qr-code.svg]]

